# htestp

[![PyPI - Version](https://img.shields.io/pypi/v/htestp.svg)](https://pypi.org/project/htestp)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/htestp.svg)](https://pypi.org/project/htestp)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install htestp
```

## License

`htestp` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
